package kubecaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module V1.Taint

The node this Taint is attached to has the "effect" on any pod that does not tolerate the Taint.

type t
val to_yojson : t -> Yojson.Safe.t
val make : ?value:string -> ?time_added:Kubernetes.Definitions.Apimachinery.Pkg.Apis.Meta.V1.Time.t -> key:string -> effect:string -> unit -> t
val effect : t -> string

Required. The effect of the taint on pods that do not tolerate the taint. Valid effects are No_schedule, Prefer_no_schedule and No_execute.

val key : t -> string

Required. The taint key to be applied to a node.

Time_added represents the time at which the taint was added. It is only written for No_execute taints.

val value : t -> string option

Required. The taint value corresponding to the taint key.

module Object : Object.S with type value := t