package kubecaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module V1.Tcp_socket_action

Tcp_socket_action describes an action based on opening a socket

type t
val to_yojson : t -> Yojson.Safe.t
val host : t -> string option

Optional: Host name to connect to, defaults to the pod Ip.

Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an Iana_svc_name.

module Object : Object.S with type value := t